@@ -28,4 +28,14 @@ test_that("na.rm", {
     sum(is.na(stretch(d, na.rm = TRUE)$r)),
     0
   )
-})
\ No newline at end of file
+})
+
+test_that("retract works", {
+  cd <- as_cordf(retract(stretch(d)))
+  expect_equal(d, cd)
+  expect_is(d, "cor_df")
+})
+
+test_that("remove.dups works", {
+  expect_is(stretch(d, remove.dups = TRUE), "data.frame")
+})
